@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Store::SQL;
-our $VERSION = '1.20260226';
+our $VERSION = '1.20260301';
 use strict;
 use warnings;
 
@@ -63,12 +63,14 @@ sub retrieve {
         push @params, $args{end};
     };
     if ( $args{author} ) {
-        $query .= $self->grammar->and_arg('a.org_name');
-        push @params, $args{author};
+        my ( $op, $val ) = $self->_negate_arg( $args{author} );
+        $query .= $self->grammar->and_arg('a.org_name', $op);
+        push @params, $val;
     };
     if ( $args{from_domain} ) {
-        $query .= $self->grammar->and_arg('fd.domain');
-        push @params, $args{from_domain};
+        my ( $op, $val ) = $self->_negate_arg( $args{from_domain} );
+        $query .= $self->grammar->and_arg('fd.domain', $op);
+        push @params, $val;
     };
 
     my $reports = $self->query( $query, \@params );
@@ -80,6 +82,14 @@ sub retrieve {
     return $reports;
 }
 
+sub _negate_arg {
+    my ( $self, $val ) = @_;
+    if ( substr($val, 0, 1) eq '!' ) {
+        return ( '!=', substr($val, 1) );
+    }
+    return ( '=', $val );
+}
+
 sub next_todo {
     my ( $self ) = @_;
 
@@ -689,7 +699,7 @@ Mail::DMARC::Report::Store::SQL - store and retrieve reports from a SQL RDBMS
 
 =head1 VERSION
 
-version 1.20260226
+version 1.20260301
 
 =head1 DESCRIPTION
 
